#[repr(u8)]pub enum HostdiscondetectStatus {
VALUE0 = 0,
VALUE1 = 1,
}Variants
VALUE0 = 0
USB cable disconnect has not been detected at the local host
VALUE1 = 1
USB cable disconnect has been detected at the local host
Implementations