#[repr(u8)]pub enum Usb1VbusDetectSetVbusSourceSel {
VALUE0 = 0,
VALUE1 = 1,
VALUE2 = 2,
_RESERVED_3 = 3,
}Variants
VALUE0 = 0
Use the VBUS_VALID comparator results for signal reported to the USB controller (Default)
VALUE1 = 1
Use the Session Valid comparator results for signal reported to the USB controller
VALUE2 = 2
Use the Session Valid comparator results for signal reported to the USB controller
_RESERVED_3 = 3
Implementations