#[repr(u8)]pub enum Usb1VbusDetectVbusvalidSel {
VALUE0 = 0,
VALUE1 = 1,
}Variants
VALUE0 = 0
Use the VBUS_VALID comparator results for signal reported to the USB controller (Default)
VALUE1 = 1
Use the VBUS_VALID_3V detector results for signal reported to the USB controller
Implementations